<?php
/**
 * Digiwan functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Digiwan
 * @since Digiwan 1.0
 */

if ( ! function_exists( 'digiwan_styles' ) ) :

	/**
	 * Enqueue styles.
	 *
	 * @since Digiwan 1.0
	 *
	 * @return void
	 */
	function digiwan_styles() {
		// Register theme stylesheet.
		$theme_version = wp_get_theme()->get( 'Version' );

		$version_string = is_string( $theme_version ) ? $theme_version : false;
		wp_register_style(
			'custom-core',
			get_template_directory_uri() . '/assets/css/custom-core.css',
			array(),
			$version_string
		);

		wp_register_style(
			'admin-page',
			get_template_directory_uri() . '/assets/css/admin.css',
			array(),
			$version_string
		);

		// Enqueue theme stylesheet.
		wp_enqueue_style( 'custom-core' );
		wp_enqueue_style( 'admin-page' );
	}

endif;

add_action( 'init', 'digiwan_styles' );

 /**
 * Load Block Function.
 */
require_once get_template_directory() . '/inc/init.php';

/**
 * Enqueue block stylesheets.
 */

if ( ! function_exists( 'digiwan_block_stylesheets' ) ) :
	/**
	 * Enqueue custom block stylesheets
	 *
	 * @since Digiwan 1.0
	 * @return void
	 */
	function digiwan_block_stylesheets() {
		/**
		 * The wp_enqueue_block_style() function allows us to enqueue a stylesheet
		 * for a specific block. These will only get loaded when the block is rendered
		 * (both in the editor and on the front end), improving performance
		 * and reducing the amount of data requested by visitors.
		 *
		 * See https://make.wordpress.org/core/2021/12/15/using-multiple-stylesheets-per-block/ for more info.
		 */

		wp_enqueue_block_style(
			'core',
			array(
				'handle' => 'custom-core',
				'src'    => get_parent_theme_file_uri( 'assets/css/custom-core.css' ),
				'ver'    => wp_get_theme( get_template() )->get( 'Version' ),
				'path'   => get_parent_theme_file_path( 'assets/css/custom-core.css' ),
			)
		);


		wp_enqueue_block_style(
			'core/button',
			array(
				'handle' => 'digiwan-button-style',
				'src'    => get_parent_theme_file_uri( 'assets/css/button.css' ),
				'ver'    => wp_get_theme( get_template() )->get( 'Version' ),
				'path'   => get_parent_theme_file_path( 'assets/css/button.css' ),
			)
		);

		wp_enqueue_block_style(
			'core/heading',
			array(
				'handle' => 'digiwan-heading-style',
				'src'    => get_parent_theme_file_uri( 'assets/css/heading.css' ),
				'ver'    => wp_get_theme( get_template() )->get( 'Version' ),
				'path'   => get_parent_theme_file_path( 'assets/css/heading.css' ),
			)
		);

		wp_enqueue_block_style(
			'core/paragraph',
			array(
				'handle' => 'digiwan-paragraph-style',
				'src'    => get_parent_theme_file_uri( 'assets/css/paragraph.css' ),
				'ver'    => wp_get_theme( get_template() )->get( 'Version' ),
				'path'   => get_parent_theme_file_path( 'assets/css/paragraph.css' ),
			)
		);
	}
endif;

add_action( 'init', 'digiwan_block_stylesheets' );


/**
 * Registers block patterns and categories.
 *
 * @since 1.0
 *
 * @return void
 */

function digiwan_register_block_patterns() {
	$block_pattern_categories = array(
		'digiwan_patterns' => array( 'label' => esc_html__( 'Digiwan Patterns', 'digiwan' ) ),
		'digiwan_page'    => array( 'label' => esc_html__( 'Digiwan Pages', 'digiwan' ) ),
		'digiwan'    => array( 'label' => esc_html__( 'Digiwan Theme Patterns', 'digiwan' ) ),
	);

	$block_pattern_categories = apply_filters( 'digiwan_block_pattern_categories', $block_pattern_categories );

	foreach ( $block_pattern_categories as $name => $properties ) {
		if ( ! WP_Block_Pattern_Categories_Registry::get_instance()->is_registered( $name ) ) {
			register_block_pattern_category( $name, $properties );
		}
	}

	// Theme Block Patterns Advanced With Addons

	include_once ABSPATH . 'wp-admin/includes/plugin.php';

	if ( is_plugin_active( 'kadence-blocks/kadence-blocks.php' ) ) {
		$block_patterns = array(		
			'about',
			'about-us',
			'after-header',
			'blog-page',
			'blog-section',
			'client-logo',
			'contact-information',
			'contact-us',
			'counter-stats-section',
			'cta-center',
			'cta-left',
			'our-pricing',
			'our-projects',
			'our-services',
			'our-value',
			'page-after-header',
			'pricing',
			'projects',
			'services',
			'sidebar',
			'testimonials',
			'why-choice-us',
			
		);

		/**
		 * Filters the theme block patterns.
		 *
		 * @since 1.0
		 *
		 * @param array $block_patterns List of block patterns by name.
		 */
		$block_patterns = apply_filters( 'digiwan_block_patterns', $block_patterns );

		foreach ( $block_patterns as $block_pattern ) {
		$pattern_file = get_parent_theme_file_path( '/inc/patterns/' . $block_pattern . '.php' );

		register_block_pattern(
			'digiwan/' . $block_pattern,
			require $pattern_file
		); // register_block_pattern( string $pattern_name, array $pattern_properties )
		}
	}

	// Theme Block Patterns Include Basic

	$block_patterns = array(		
		'front-page',
		'footer',
		'header',
		'single',
		'page',
		'archive',
		'search',
		'404',
	);

	/**
	 * Filters the theme block patterns.
	 *
	 * @since 1.0
	 *
	 * @param array $block_patterns List of block patterns by name.
	 */
	$block_patterns = apply_filters( 'digiwan_block_patterns', $block_patterns );

	foreach ( $block_patterns as $block_pattern ) {
		$pattern_file = get_parent_theme_file_path( '/inc/patterns/' . $block_pattern . '.php' );

		register_block_pattern(
			'digiwan/' . $block_pattern,
			require $pattern_file
		); // register_block_pattern( string $pattern_name, array $pattern_properties )
	}
}

add_action( 'init', 'digiwan_register_block_patterns', 9 );
