<?php

/**
 * Block Styles
 *
 * @link https://developer.wordpress.org/reference/functions/register_block_style/
 *
 * @package mighty_plumbers
 * @since 1.0.0
 */

if ( ! function_exists( 'digiwan_block_styles' ) ) :
	/**
	 * Register custom block styles
	 *
	 * @since Digiwan 1.0
	 * @return void
	 */
	function digiwan_block_styles() {

		register_block_style(
			'core/details',
			array(
				'name'         => 'arrow-icon-details',
				'label'        => __( 'Arrow icon', 'digiwan' ),
				/*
				 * Styles for the custom Arrow icon style of the Details block
				 */
				'inline_style' => '
				.is-style-arrow-icon-details {
					padding-top: var(--wp--preset--spacing--10);
					padding-bottom: var(--wp--preset--spacing--10);
				}

				.is-style-arrow-icon-details summary {
					list-style-type: "\2193\00a0\00a0\00a0";
				}

				.is-style-arrow-icon-details[open]>summary {
					list-style-type: "\2192\00a0\00a0\00a0";
				}',
			)
		);
		register_block_style(
			'core/post-terms',
			array(
				'name'         => 'pill',
				'label'        => __( 'Pill', 'digiwan' ),
				/*
				 * Styles variation for post terms
				 * https://github.com/WordPress/gutenberg/issues/24956
				 */
				'inline_style' => '
				.is-style-pill a,
				.is-style-pill span:not([class], [data-rich-text-placeholder]) {
					display: inline-block;
					background-color: var(--wp--preset--color--base-2);
					padding: 0.375rem 0.875rem;
					border-radius: var(--wp--preset--spacing--20);
				}

				.is-style-pill a:hover {
					background-color: var(--wp--preset--color--contrast-3);
				}',
			)
		);
		register_block_style(
			'core/list',
			array(
				'name'         => 'checkmark-list',
				'label'        => __( 'Checkmark', 'digiwan' ),
				/*
				 * Styles for the custom checkmark list block style
				 * https://github.com/WordPress/gutenberg/issues/51480
				 */
				'inline_style' => '
				ul.is-style-checkmark-list {
					list-style-type: "\2713";
				}

				ul.is-style-checkmark-list li {
					padding-inline-start: 1ch;
				}',
			)
		);
		register_block_style(
			'core/navigation',
			array(
				'name'         => 'hover-primary',
				'label'        => __( 'Hover Primary', 'digiwan' ),
				/*
				 * Styles for the custom arrow nav link block style
				 */
				'inline_style' => '				
				@media (min-width: 1024px){
					.wp-block-navigation-item{
					height: 90px;
					}	
				}
			
					
				.wp-block-navigation .wp-block-navigation-item:hover{
					color: white;
				}
					
				.wp-block-navigation-item .wp-block-navigation-link:hover{
					background-color: var(--wp--preset--color--custom-secondary);
				}',
			)
		);

        /* - Styles for custom Button Primary - */
		register_block_style(
			'core/button',
			array(
				'name'         => 'btn-primary',
				'label'        => __( 'Button Primary', 'digiwan' ),
			)
		);

        /* - Styles for custom Button Secondary - */
		register_block_style(
			'core/button',
			array(
				'name'         => 'btn-secondary',
				'label'        => __( 'Button Secondary', 'digiwan' ),
			)
		);

        /* - Styles for custom Button Transparent - */
		register_block_style(
			'core/button',
			array(
				'name'         => 'btn-transparent',
				'label'        => __( 'Button Transparent', 'digiwan' ),
            )
        );

        /* - Styles for custom Button Link - */
		register_block_style(
			'core/button',
			array(
				'name'         => 'btn-link',
				'label'        => __( 'Button Link', 'digiwan' ),
			)
		);

		/* - Styles for custom Button Link Secondary - */
		register_block_style(
			'core/button',
			array(
				'name'         => 'btn-link-secondary',
				'label'        => __( 'Button Link Secondary', 'digiwan' ),
			)
		);

        /* - Styles for custom Subheading - */
		register_block_style(
			'core/heading',
			array(
				'name'         => 'subheading',
				'label'        => __( 'Subheading', 'digiwan' ),
			)
		);

        /* - Styles for custom Heading Very Big - */
		register_block_style(
			'core/heading',
			array(
				'name'         => 'heading-very-big',
				'label'        => __( 'Heading Very Big', 'digiwan' ),
			)
		);

		/* - Styles for custom Heading Very Big - */
		register_block_style(
			'core/post-title',
			array(
				'name'         => 'heading-very-big',
				'label'        => __( 'Heading Very Big', 'digiwan' ),
			)
		);

		/* - Styles for custom Heading Very Big - */
		register_block_style(
			'core/query-title',
			array(
				'name'         => 'heading-very-big',
				'label'        => __( 'Heading Very Big', 'digiwan' ),
			)
		);

		/* - Styles for custom Heading Very Big - */
		register_block_style(
			'core/archive-title',
			array(
				'name'         => 'heading-very-big',
				'label'        => __( 'Heading Very Big', 'digiwan' ),
			)
		);

        /* - Styles for custom Heading Big - */
		register_block_style(
			'core/heading',
			array(
				'name'         => 'heading-big',
				'label'        => __( 'Heading Big', 'digiwan' ),
			)
		);

		/* - Styles for custom Heading Big - */
		register_block_style(
			'core/post-title',
			array(
				'name'         => 'heading-big',
				'label'        => __( 'Heading Big', 'digiwan' ),
			)
		);

        /* - Styles for custom Heading Medium - */
		register_block_style(
			'core/heading',
			array(
				'name'         => 'heading-medium',
				'label'        => __( 'Heading Medium', 'digiwan' ),
			)
		);

		/* - Styles for custom Heading Medium - */
		register_block_style(
			'core/post-title',
			array(
				'name'         => 'heading-medium',
				'label'        => __( 'Heading Medium', 'digiwan' ),
			)
		);

        /* - Styles for custom Heading Standart - */
		register_block_style(
			'core/heading',
			array(
				'name'         => 'heading-standart',
				'label'        => __( 'Heading Standart', 'digiwan' ),
			)
		);

		/* - Styles for custom Heading Standart - */
		register_block_style(
			'core/post-title',
			array(
				'name'         => 'heading-standart',
				'label'        => __( 'Heading Standart', 'digiwan' ),
			)
		);

        /* - Styles for custom Heading Small - */
		register_block_style(
			'core/heading',
			array(
				'name'         => 'heading-small',
				'label'        => __( 'Heading Small', 'digiwan' ),
			)
		);

		/* - Styles for custom Heading Small - */
		register_block_style(
			'core/post-title',
			array(
				'name'         => 'heading-small',
				'label'        => __( 'Heading Small', 'digiwan' ),
			)
		);

        /* - Styles for custom Heading Extra Small - */
		register_block_style(
			'core/heading',
			array(
				'name'         => 'heading-xsmall',
				'label'        => __( 'Heading Extra Small', 'digiwan' ),
			)
		);

		/* - Styles for custom Heading Extra Small - */
		register_block_style(
			'core/post-title',
			array(
				'name'         => 'heading-xsmall',
				'label'        => __( 'Heading Extra Small', 'digiwan' ),
			)
		);

        /* - Styles for custom Block Quote Style - */
		register_block_style(
			'core/paragraph',
			array(
				'name'         => 'block-quote-paragraph',
				'label'        => __( 'Block Quote Style', 'digiwan' ),
			)
		);

        /* - Styles for custom Quote Style - */
		register_block_style(
			'core/paragraph',
			array(
				'name'         => 'quote-paragraph',
				'label'        => __( 'Quote Style', 'digiwan' ),
			)
		);

		/* - Styles for custom Body Small - */
		register_block_style(
			'core/paragraph',
			array(
				'name'         => 'body-small',
				'label'        => __( 'Body Small', 'digiwan' ),
			)
		);
	}
endif;

add_action( 'init', 'digiwan_block_styles' );